function varargout = micgui(varargin)
% MICGUI M-file for micgui.fig
%      MICGUI, by itself, creates a new MICGUI or raises the existing
%      singleton*.
%
%      H = MICGUI returns the handle to a new MICGUI or the handle to
%      the existing singleton*.
%
%      MICGUI('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in MICGUI.M with the given input arguments.
%
%      MICGUI('Property','Value',...) creates a new MICGUI or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before micgui_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to micgui_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help micgui

% Last Modified by GUIDE v2.5 19-Dec-2002 17:14:17

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @micgui_OpeningFcn, ...
                   'gui_OutputFcn',  @micgui_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before micgui is made visible.
function micgui_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to micgui (see VARARGIN)

% Choose default command line output for micgui
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes micgui wait for user response (see UIRESUME)
% uiwait(handles.figure1);

h1 = handles.slider1;
h2 = handles.slider2;
set(h1, 'Value',0)
set(h2, 'Value', 1)
he = handles.eqn;
set(he, 'String', ['r = |', num2str(0), ' + ', num2str(1), ' cos t |'])
theta = 0:0.01:2*pi;
r = abs(0 + 1*cos(theta));
set(gcf, 'DefaultLineLineWidth',2)
polar(theta,r,'r')
title('dB vs. angle')

% --- Outputs from this function are returned to the command line.
function varargout = micgui_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes during object creation, after setting all properties.
function slider1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to slider1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background, change
%       'usewhitebg' to 0 to use default.  See ISPC and COMPUTER.
usewhitebg = 1;
if usewhitebg
    set(hObject,'BackgroundColor',[.9 .9 .9]);
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


% --- Executes on slider movement.
function slider1_Callback(hObject, eventdata, handles)
% hObject    handle to slider1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider

h1 = handles.slider1;
h2 = handles.slider2;
a = get(h1, 'Value');
set(h2, 'Value', 1-a)
b = get(h2, 'Value');
he = handles.eqn;
set(he, 'String', ['r = |', num2str(a), ' + ', num2str(b), ' cos t |'])
theta = 0:0.01:2*pi;
r = abs(a + b*cos(theta));
set(gcf, 'DefaultLineLineWidth',2)
polar(theta,r,'r')
title('dB vs. angle')

% --- Executes during object creation, after setting all properties.
function slider2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to slider2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background, change
%       'usewhitebg' to 0 to use default.  See ISPC and COMPUTER.
usewhitebg = 1;
if usewhitebg
    set(hObject,'BackgroundColor',[.9 .9 .9]);
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


% --- Executes on slider movement.
function slider2_Callback(hObject, eventdata, handles)
% hObject    handle to slider2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider

h1 = handles.slider1;
h2 = handles.slider2;
b = get(h2, 'Value');
set(h1, 'Value', 1-b);
a = get(h1, 'Value');
he = handles.eqn;
set(he, 'String', ['r = |', num2str(a), ' + ', num2str(b), ' cos t |']);
theta = 0:0.01:2*pi;
r = abs(a + b*cos(theta));
set(gcf, 'DefaultLineLineWidth',2);
polar(theta,r,'r')
title('dB vs. angle')